@@ -52,13 +52,9 @@ class TestCase(unittest.TestCase):
         except FileNotFoundError:
             'already removed'
 
-    @staticmethod
-    def get_commit_message():
-        return input("Enter commit message: ")
-
     def push(self):
         os.system('git push')
-        os.system(f'git commit -am "{self.get_commit_message()}"')
+        os.system(f'git commit -am "{get_commit_message()}"')
 
     def build_and_publish(self):
         self.push()
@@ -126,4 +122,7 @@ def time_it(function, *args, description='run process', **kwargs):
     return result
 
 def to_camel_case(text):
-    return ''.join(text.title().split('-'))
\ No newline at end of file
+    return ''.join(text.title().split('-'))
+
+def get_commit_message():
+    return input("Enter commit message: ")
\ No newline at end of file
